@@ -31,6 +31,7 @@ from .selector import Selector
 from .selector import selector_to_sql
 from .tables import journals_table
 from .tables import list_columns
+from .tables import list_columns_sorted
 from .tables import make_journals_table
 from .tables import make_settings_table
 from .tables import make_submissions_table
@@ -116,19 +117,28 @@ def copy_cursors(db_dest: 'FADatabase', cursors: list['FADatabaseCursor'] = None
             table_dest.insert(cursor.table.format_dict(entry), replace=True)
 
 
-def format_list(obj: list[Value]) -> str:
-    return "".join(f"|{e}|" for e in sorted(set(map(str, obj)), key=str.lower))
+def format_list(obj: list[Value], *, sort: bool = False) -> str:
+    return "".join(f"|{e}|" for e in (sorted(obj) if sort else obj))
 
 
 def unpack_list(obj: str) -> list[str]:
     return [e for e in obj.split("|") if e]
 
 
+def join_lists(a: list[Value], b: list[Value]) -> list[Value]:
+    return a + [e for e in b if b not in a]
+
+
+def disjoin_lists(a: list[Value], b: list[Value]) -> list[Value]:
+    return [e for e in a if e not in b]
+
+
 class FADatabaseTable:
     def __init__(self, database: 'FADatabase', table: str):
         self.database: 'FADatabase' = database
         self.table: str = table.upper()
         self.list_columns: list[str] = list(map(str.upper, list_columns.get(self.table, [])))
+        self.list_columns_sorted: list[str] = list(map(str.upper, list_columns_sorted.get(self.table, [])))
 
     def __len__(self) -> int:
         return self.database.connection.execute(f"SELECT COUNT(*) FROM {self.table}").fetchone()[0]
@@ -175,9 +185,10 @@ class FADatabaseTable:
         elif not (item := self[key]):
             return False
         item = {k: item[k] for k in values.keys()}
-        item_new = {k: sorted(filter(bool, set(item[k] + v)), key=str.lower) for k, v in values.items()}
-        self.update({k: format_list(v) for k, v in item_new.items()}, key) if item_new != item else None
-        return item_new != item
+        item_new = {k: join_lists(item[k], v) for k, v in values.items()}
+        if diff := any({*item[k]} != {*v} for k, v in item_new.items()):
+            self.update({k: format_list(v, sort=k in self.list_columns_sorted) for k, v in item_new.items()}, key)
+        return diff
 
     def remove_from_list(self, key: Key, values: dict[str, list[Value]]) -> bool:
         if not (values := {k.upper(): v for k, v in values.items() if v and k.upper() in self.list_columns}):
@@ -185,9 +196,10 @@ class FADatabaseTable:
         elif not (item := self[key]):
             return False
         item = {k: item[k] for k in values.keys()}
-        item_new = {k: sorted(filter(bool, set(item[k]) - set(v)), key=str.lower) for k, v in values.items()}
-        self.update({k: format_list(v) for k, v in item_new.items()}, key) if item_new != item else None
-        return item_new != item
+        item_new = {k: disjoin_lists(item[k], v) for k, v in values.items()}
+        if diff := any({*item[k]} != {*v} for k, v in item_new.items()):
+            self.update({k: format_list(v, sort=k in self.list_columns_sorted) for k, v in item_new.items()}, key)
+        return diff
 
     def reload(self):
         self.__init__(self.database, self.table)
@@ -196,19 +208,21 @@ class FADatabaseTable:
 
     def format_dict(self, obj: Entry) -> dict[str, Value]:
         obj = {k.upper().replace("_", ""): v for k, v in obj.items()}
-        obj = {k: format_list(v) if isinstance(v := obj.get(k, ""), list) else v for k in self.columns}
+        obj = {k: format_list(v, sort=k in self.list_columns_sorted) if isinstance(v := obj.get(k, ""), list) else v
+               for k in self.columns}
         return obj
 
-    def select(self, query: Selector = None, values: list[Value] = None, columns: list[str] = None,
+    def select(self, query: Selector = None, columns: list[str] = None,
                order: list[str] = None, limit: int = 0, offset: int = 0
                ) -> 'FADatabaseCursor':
+        sql, values = selector_to_sql(query) if query else ("", [])
         cursor: Cursor = self.database.execute(
             f"""SELECT {','.join(columns := columns or self.columns)} FROM {self.table}
-                    {f' WHERE {selector_to_sql(query)}' if query else ''}
+                    {f' WHERE {sql}' if sql else ''}
                     {f' ORDER BY {",".join(order)}' if order else ''}
                     {f' LIMIT {limit}' if limit > 0 else ''}
                     {f' OFFSET {offset}' if limit > 0 and offset > 0 else ''}""",
-            values or [])
+            values)
         return FADatabaseCursor(cursor, columns, self)
 
     def select_sql(self, where: str = "", values: list[Value] = None, columns: list[str] = None,
@@ -383,25 +397,19 @@ class FADatabaseCursor:
 
 
 class FADatabase:
-    def __init__(self, database_path: Union[str, PathLike]):
+    def __init__(self, database_path: Union[str, PathLike], *, make: bool = True):
         self.database_path: Path = Path(database_path).resolve()
         self.connection: Connection = connect(self.database_path)
 
-        if journals_table not in (tables := self.tables):
-            make_journals_table(self.connection)
-        if settings_table not in tables:
-            make_settings_table(self.connection)
-        if submissions_table not in tables:
-            make_submissions_table(self.connection)
-        if users_table not in tables:
-            make_users_table(self.connection)
-
         self.journals: FADatabaseJournals = FADatabaseJournals(self, journals_table)
         self.settings: FADatabaseSettings = FADatabaseSettings(self, settings_table)
         self.submissions: FADatabaseSubmissions = FADatabaseSubmissions(self, submissions_table)
         self.users: FADatabaseUsers = FADatabaseUsers(self, users_table)
         self.committed_changes: int = self.total_changes
 
+        if make:
+            self.make_tables()
+
     def __getitem__(self, table: str):
         return FADatabaseTable(self, table)
 
@@ -417,13 +425,6 @@ class FADatabase:
     def __exit__(self, exc_type, exc_val, exc_tb):
         self.close()
 
-    def is_open(self) -> bool:
-        try:
-            self.connection.execute("SELECT * FROM sqlite_master")
-            return True
-        except ProgrammingError:
-            return False
-
     @property
     def tables(self) -> list[str]:
         return [
@@ -452,6 +453,27 @@ class FADatabase:
     def files_folder(self) -> Path:
         return self.database_path.parent / self.settings["FILESFOLDER"]
 
+    def is_open(self) -> bool:
+        try:
+            self.connection.execute("SELECT * FROM sqlite_master")
+            return True
+        except ProgrammingError:
+            return False
+
+    def make_tables(self):
+        if journals_table not in (tables := self.tables):
+            make_journals_table(self.connection)
+            self.journals.reload()
+        if settings_table not in tables:
+            make_settings_table(self.connection)
+            self.settings.reload()
+        if submissions_table not in tables:
+            make_submissions_table(self.connection)
+            self.submissions.reload()
+        if users_table not in tables:
+            make_users_table(self.connection)
+            self.users.reload()
+
     def move_files_folder(self, new_folder: Union[str, PathLike]) -> Path:
         new_folder = Path(new_folder)
         new_folder = new_folder if new_folder.is_absolute() else (self.database_path.parent / new_folder)
